@@ -277,3 +277,10 @@ def test_list_installed_deps_explicit_cli(
         assert "pip==" in result.out
     else:
         assert "pip==" not in result.out
+
+
+def test_usedevelop_with_nonexistent_basepython(tox_project: ToxProjectCreator) -> None:
+    ini = "[testenv]\nusedevelop = true\n[testenv:unused]\nbasepython = /nonexistent/bin/python"
+    project = tox_project({"tox.ini": ini})
+    result = project.run()
+    assert result.code == 0
