@@ -2,14 +2,17 @@ from __future__ import annotations
 
 import sys
 from pathlib import Path
+from typing import TYPE_CHECKING
 
 import pytest
 
 from tox.journal import EnvJournal
-from tox.pytest import ToxProjectCreator
 from tox.tox_env.package import PathPackage
 from tox.tox_env.python.runner import PythonRun
 
+if TYPE_CHECKING:
+    from tox.pytest import ToxProjectCreator
+
 
 def test_deps_config_path_req(tox_project: ToxProjectCreator) -> None:
     project = tox_project(
@@ -30,7 +33,7 @@ def test_deps_config_path_req(tox_project: ToxProjectCreator) -> None:
 def test_journal_package_empty() -> None:
     journal = EnvJournal(enabled=True, name="a")
 
-    PythonRun._handle_journal_package(journal, [])
+    PythonRun._handle_journal_package(journal, [])  # noqa: SLF001
 
     content = journal.content
     assert content == {}
@@ -41,7 +44,7 @@ def test_journal_one_wheel_file(tmp_path: Path) -> None:
     wheel.write_bytes(b"magical")
     journal = EnvJournal(enabled=True, name="a")
 
-    PythonRun._handle_journal_package(journal, [PathPackage(wheel)])
+    PythonRun._handle_journal_package(journal, [PathPackage(wheel)])  # noqa: SLF001
 
     content = journal.content
     assert content == {
@@ -60,7 +63,7 @@ def test_journal_multiple_wheel_file(tmp_path: Path) -> None:
     wheel_2.write_bytes(b"magic")
     journal = EnvJournal(enabled=True, name="a")
 
-    PythonRun._handle_journal_package(journal, [PathPackage(wheel_1), PathPackage(wheel_2)])
+    PythonRun._handle_journal_package(journal, [PathPackage(wheel_1), PathPackage(wheel_2)])  # noqa: SLF001
 
     content = journal.content
     assert content == {
@@ -82,7 +85,7 @@ def test_journal_multiple_wheel_file(tmp_path: Path) -> None:
 def test_journal_package_dir(tmp_path: Path) -> None:
     journal = EnvJournal(enabled=True, name="a")
 
-    PythonRun._handle_journal_package(journal, [PathPackage(tmp_path)])
+    PythonRun._handle_journal_package(journal, [PathPackage(tmp_path)])  # noqa: SLF001
 
     content = journal.content
     assert content == {
@@ -95,7 +98,16 @@ def test_journal_package_dir(tmp_path: Path) -> None:
 
 def test_package_temp_dir_view(tox_project: ToxProjectCreator, demo_pkg_inline: Path) -> None:
     project = tox_project({"tox.ini": "[testenv]\npackage=wheel"})
-    result = project.run("r", "-vv", "-e", "py", "--root", str(demo_pkg_inline))
+    result = project.run(
+        "r",
+        "-vv",
+        "-e",
+        "py",
+        "--root",
+        str(demo_pkg_inline),
+        "--workdir",
+        str(project.path / ".tox"),
+    )
     result.assert_success()
     wheel_name = "demo_pkg_inline-1.0.0-py3-none-any.whl"
     session_path = Path(".tmp") / "package" / "1" / wheel_name
