@@ -8,7 +8,7 @@ from tox.config.sets import ConfigSet
 
 class EnvDockerConfigSet(ConfigSet):
     def register_config(self) -> None:
-        def factory(container_name: object) -> str:  # noqa: U100
+        def factory(container_name: object) -> str:  # noqa: ARG001
             raise NotImplementedError
 
         self.add_config(
